%--------------------------------------------------------------------------
% File     : GRP024-4 : TPTP v3.0.1. Released v1.0.0.
% Domain   : Group Theory
% Problem  : Associativity of commutator
% Version  : [MOW76] (equality) axioms : Augmented.
% English  : The commutator operation is associative if and only if the 
%            commutator of any two elements lies in the center of the 
%            group, i.e. [[X,Y],Z]=[X,[Y,Z]] iff [U,V]*W=W*[U,V].

% Refs     : [Kur56] Kurosh (1956), The Theory of Groups
%          : [MOW76] McCharen et al. (1976), Problems and Experiments for a
%          : [ML92]  McCune & Lusk (1992), A Challenging Theorem of Levi
% Source   : [ML92]
% Names    : THEOREM (Levi) [ML92]

% Status   : Satisfiable
% Rating   : 0.67 v2.7.0, 0.33 v2.6.0, 0.86 v2.5.0, 1.00 v2.0.0
% Syntax   : Number of clauses     :    8 (   1 non-Horn;   6 unit;   2 RR)
%            Number of atoms       :   10 (  10 equality)
%            Maximal clause size   :    2 (   1 average)
%            Number of predicates  :    1 (   0 propositional; 2-2 arity)
%            Number of functors    :   10 (   7 constant; 0-2 arity)
%            Number of variables   :    9 (   0 singleton)
%            Maximal term depth    :    5 (   3 average)

% Comments : A textbook proof can be found in [Kur56].
%          : Uses an explicit formulation of the commutator
%--------------------------------------------------------------------------
%----Include group theory axioms 
include('Axioms/GRP004-0.ax').
%--------------------------------------------------------------------------
%----Redundant two axioms
cnf(right_identity,axiom,
    ( multiply(X,identity) = X )).

cnf(right_inverse,axiom,
    ( multiply(X,inverse(X)) = identity )).

%----Definition of the commutator 
cnf(commutator,axiom,
    ( commutator(X,Y) = multiply(X,multiply(Y,multiply(inverse(X),inverse(Y)))) )).

cnf(associativity_or_center,negated_conjecture,
    ( commutator(commutator(a,b),c) = commutator(a,commutator(b,c))
    | multiply(commutator(e,f),g) = multiply(g,commutator(e,f)) )).

cnf(not_both_associativity_and_center,negated_conjecture,
    ( commutator(commutator(a,b),c) != commutator(a,commutator(b,c))
    | multiply(commutator(e,f),g) != multiply(g,commutator(e,f)) )).

%--------------------------------------------------------------------------
